=======
Credits
=======

Development Lead
----------------
* Taylor Salo <taylor dot salo at pennmedicine dot upenn dot edu>

Contributors
------------
* Matt Cieslak <matthew dot cieslak at pennmedicine dot upenn dot edu>

Principal Investigator
----------------------
* Theodore Satterthwaite <theodore dot satterthwaite at pennmedicine dot upenn dot edu>

Previous Contributors
---------------------
* Sydney Covitz <sydney dot covitz at pennmedicine dot upenn dot edu> (previous development lead)

* Tinashe Tapera <tinashe dot tapera at pennmedicine dot upenn dot edu>
